#[repr(transparent)]pub struct SlabFlags(u8);Expand description
Flags for SlabHdr.
Tuple Fields
0: u8Implementations
Sourceimpl SlabFlags
impl SlabFlags
Sourcepub const fn zeroed() -> Self
pub const fn zeroed() -> Self
Returns a new set with all bits of the backed-storage set to zero.
Sourcepub fn has_any(self, rhs: impl Into<Self>) -> bool
pub fn has_any(self, rhs: impl Into<Self>) -> bool
Returns true if this set contains any flags in the rhs set.
This performs the & operation on the underlying value and check if the results is
non-zero.