Slab

Struct Slab 

#[repr(C)]
pub struct Slab<I> { pub hdr: SlabHdr<I>, pub free: [I], }
Implementation of uma_slab and uma_slab_refcnt.

We use slightly different mechanism here but has the same memory layout.

Safety

Adding more fields into this struct without knowing how it work can cause undefined behavior in some places.

Fields

hdr: SlabHdr<I>free: [I]

Implementations

Source

impl<I> Slab<I>

pub fn alloc_item(&mut self)

See slab_alloc_item on the Orbis for a reference.

Reference offsets
VersionOffset
PS4 11.000x141FE0