#[repr(C)]pub struct Slab<I> {
pub hdr: SlabHdr<I>,
pub free: [I],
}Expand description
Implementation of uma_slab and uma_slab_refcnt.
We use slightly different mechanism here but has the same memory layout.
Safety
Adding more fields into this struct without knowing how it work can cause undefined behavior in some places.
Fields
hdr: SlabHdr<I>free: [I]